==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/BollingerBandWidthIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var BollingerBandWidthIndicatorDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BollingerBandWidthIndicatorDescription, _super);
    function BollingerBandWidthIndicatorDescription() {
        var _this = _super.call(this) || this;
        _this.ed = 0;
        _this.eb = 0;
        return _this;
    }
    BollingerBandWidthIndicatorDescription.prototype.get_type = function () {
        return "BollingerBandWidthIndicator";
    };
    Object.defineProperty(BollingerBandWidthIndicatorDescription.prototype, "period", {
        get: function () {
            return this.ed;
        },
        set: function (a) {
            this.ed = a;
            this.e("Period");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BollingerBandWidthIndicatorDescription.prototype, "multiplier", {
        get: function () {
            return this.eb;
        },
        set: function (a) {
            this.eb = a;
            this.e("Multiplier");
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandWidthIndicatorDescription.$t = markType(BollingerBandWidthIndicatorDescription, 'BollingerBandWidthIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return BollingerBandWidthIndicatorDescription;
}(StrategyBasedIndicatorDescription));
export { BollingerBandWidthIndicatorDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/BollingerBandWidthIndicatorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicatorDescription } from "./StrategyBasedIndicatorDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var BollingerBandWidthIndicatorDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BollingerBandWidthIndicatorDescription, _super);
    function BollingerBandWidthIndicatorDescription() {
        var _this = _super.call(this) || this;
        _this.gp = 0;
        _this.gn = 0;
        return _this;
    }
    BollingerBandWidthIndicatorDescription.prototype.get_type = function () {
        return "BollingerBandWidthIndicator";
    };
    Object.defineProperty(BollingerBandWidthIndicatorDescription.prototype, "period", {
        get: function () {
            return this.gp;
        },
        set: function (a) {
            this.gp = a;
            this.g("Period");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BollingerBandWidthIndicatorDescription.prototype, "multiplier", {
        get: function () {
            return this.gn;
        },
        set: function (a) {
            this.gn = a;
            this.g("Multiplier");
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandWidthIndicatorDescription.$t = markType(BollingerBandWidthIndicatorDescription, 'BollingerBandWidthIndicatorDescription', StrategyBasedIndicatorDescription.$);
    return BollingerBandWidthIndicatorDescription;
}(StrategyBasedIndicatorDescription));
export { BollingerBandWidthIndicatorDescription };
